@@ -1,6 +1,6 @@
 package Net::GitHub::V2::Object;
 
-use Moose;
+use Any::Moose;
 
 our $VERSION = '0.07';
 our $AUTHORITY = 'cpan:FAYLAND';
@@ -36,7 +36,7 @@ sub raw {
     return $self->get( "blob/show/$owner/$repo/$sha1" );
 }
 
-no Moose;
+no Any::Moose;
 __PACKAGE__->meta->make_immutable;
 
 1;
